import { ExceptionOptionType as __ExceptionOptionType } from "@aws-sdk/smithy-client";
import { CodeStarServiceException as __BaseException } from "./CodeStarServiceException";
export interface AssociateTeamMemberRequest {
    
    projectId: string | undefined;
    
    clientRequestToken?: string;
    
    userArn: string | undefined;
    
    projectRole: string | undefined;
    
    remoteAccessAllowed?: boolean;
}
export declare namespace AssociateTeamMemberRequest {
    
    const filterSensitiveLog: (obj: AssociateTeamMemberRequest) => any;
}
export interface AssociateTeamMemberResult {
    
    clientRequestToken?: string;
}
export declare namespace AssociateTeamMemberResult {
    
    const filterSensitiveLog: (obj: AssociateTeamMemberResult) => any;
}

export declare class ConcurrentModificationException extends __BaseException {
    readonly name: "ConcurrentModificationException";
    readonly $fault: "server";
    
    constructor(opts: __ExceptionOptionType<ConcurrentModificationException, __BaseException>);
}

export declare class InvalidServiceRoleException extends __BaseException {
    readonly name: "InvalidServiceRoleException";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<InvalidServiceRoleException, __BaseException>);
}

export declare class LimitExceededException extends __BaseException {
    readonly name: "LimitExceededException";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<LimitExceededException, __BaseException>);
}

export declare class ProjectConfigurationException extends __BaseException {
    readonly name: "ProjectConfigurationException";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<ProjectConfigurationException, __BaseException>);
}

export declare class ProjectNotFoundException extends __BaseException {
    readonly name: "ProjectNotFoundException";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<ProjectNotFoundException, __BaseException>);
}

export declare class TeamMemberAlreadyAssociatedException extends __BaseException {
    readonly name: "TeamMemberAlreadyAssociatedException";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<TeamMemberAlreadyAssociatedException, __BaseException>);
}

export declare class ValidationException extends __BaseException {
    readonly name: "ValidationException";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<ValidationException, __BaseException>);
}

export interface CodeCommitCodeDestination {
    
    name: string | undefined;
}
export declare namespace CodeCommitCodeDestination {
    
    const filterSensitiveLog: (obj: CodeCommitCodeDestination) => any;
}

export interface GitHubCodeDestination {
    
    name: string | undefined;
    
    description?: string;
    
    type: string | undefined;
    
    owner: string | undefined;
    
    privateRepository: boolean | undefined;
    
    issuesEnabled: boolean | undefined;
    
    token: string | undefined;
}
export declare namespace GitHubCodeDestination {
    
    const filterSensitiveLog: (obj: GitHubCodeDestination) => any;
}

export interface CodeDestination {
    
    codeCommit?: CodeCommitCodeDestination;
    
    gitHub?: GitHubCodeDestination;
}
export declare namespace CodeDestination {
    
    const filterSensitiveLog: (obj: CodeDestination) => any;
}

export interface S3Location {
    
    bucketName?: string;
    
    bucketKey?: string;
}
export declare namespace S3Location {
    
    const filterSensitiveLog: (obj: S3Location) => any;
}

export interface CodeSource {
    
    s3: S3Location | undefined;
}
export declare namespace CodeSource {
    
    const filterSensitiveLog: (obj: CodeSource) => any;
}

export interface Code {
    
    source: CodeSource | undefined;
    
    destination: CodeDestination | undefined;
}
export declare namespace Code {
    
    const filterSensitiveLog: (obj: Code) => any;
}

export interface ToolchainSource {
    
    s3: S3Location | undefined;
}
export declare namespace ToolchainSource {
    
    const filterSensitiveLog: (obj: ToolchainSource) => any;
}

export interface Toolchain {
    
    source: ToolchainSource | undefined;
    
    roleArn?: string;
    
    stackParameters?: {
        [key: string]: string;
    };
}
export declare namespace Toolchain {
    
    const filterSensitiveLog: (obj: Toolchain) => any;
}
export interface CreateProjectRequest {
    
    name: string | undefined;
    
    id: string | undefined;
    
    description?: string;
    
    clientRequestToken?: string;
    
    sourceCode?: Code[];
    
    toolchain?: Toolchain;
    
    tags?: {
        [key: string]: string;
    };
}
export declare namespace CreateProjectRequest {
    
    const filterSensitiveLog: (obj: CreateProjectRequest) => any;
}
export interface CreateProjectResult {
    
    id: string | undefined;
    
    arn: string | undefined;
    
    clientRequestToken?: string;
    
    projectTemplateId?: string;
}
export declare namespace CreateProjectResult {
    
    const filterSensitiveLog: (obj: CreateProjectResult) => any;
}

export declare class ProjectAlreadyExistsException extends __BaseException {
    readonly name: "ProjectAlreadyExistsException";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<ProjectAlreadyExistsException, __BaseException>);
}

export declare class ProjectCreationFailedException extends __BaseException {
    readonly name: "ProjectCreationFailedException";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<ProjectCreationFailedException, __BaseException>);
}
export interface CreateUserProfileRequest {
    
    userArn: string | undefined;
    
    displayName: string | undefined;
    
    emailAddress: string | undefined;
    
    sshPublicKey?: string;
}
export declare namespace CreateUserProfileRequest {
    
    const filterSensitiveLog: (obj: CreateUserProfileRequest) => any;
}
export interface CreateUserProfileResult {
    
    userArn: string | undefined;
    
    displayName?: string;
    
    emailAddress?: string;
    
    sshPublicKey?: string;
    
    createdTimestamp?: Date;
    
    lastModifiedTimestamp?: Date;
}
export declare namespace CreateUserProfileResult {
    
    const filterSensitiveLog: (obj: CreateUserProfileResult) => any;
}

export declare class UserProfileAlreadyExistsException extends __BaseException {
    readonly name: "UserProfileAlreadyExistsException";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<UserProfileAlreadyExistsException, __BaseException>);
}
export interface DeleteProjectRequest {
    
    id: string | undefined;
    
    clientRequestToken?: string;
    
    deleteStack?: boolean;
}
export declare namespace DeleteProjectRequest {
    
    const filterSensitiveLog: (obj: DeleteProjectRequest) => any;
}
export interface DeleteProjectResult {
    
    stackId?: string;
    
    projectArn?: string;
}
export declare namespace DeleteProjectResult {
    
    const filterSensitiveLog: (obj: DeleteProjectResult) => any;
}
export interface DeleteUserProfileRequest {
    
    userArn: string | undefined;
}
export declare namespace DeleteUserProfileRequest {
    
    const filterSensitiveLog: (obj: DeleteUserProfileRequest) => any;
}
export interface DeleteUserProfileResult {
    
    userArn: string | undefined;
}
export declare namespace DeleteUserProfileResult {
    
    const filterSensitiveLog: (obj: DeleteUserProfileResult) => any;
}
export interface DescribeProjectRequest {
    
    id: string | undefined;
}
export declare namespace DescribeProjectRequest {
    
    const filterSensitiveLog: (obj: DescribeProjectRequest) => any;
}

export interface ProjectStatus {
    
    state: string | undefined;
    
    reason?: string;
}
export declare namespace ProjectStatus {
    
    const filterSensitiveLog: (obj: ProjectStatus) => any;
}
export interface DescribeProjectResult {
    
    name?: string;
    
    id?: string;
    
    arn?: string;
    
    description?: string;
    
    clientRequestToken?: string;
    
    createdTimeStamp?: Date;
    
    stackId?: string;
    
    projectTemplateId?: string;
    
    status?: ProjectStatus;
}
export declare namespace DescribeProjectResult {
    
    const filterSensitiveLog: (obj: DescribeProjectResult) => any;
}
export interface DescribeUserProfileRequest {
    
    userArn: string | undefined;
}
export declare namespace DescribeUserProfileRequest {
    
    const filterSensitiveLog: (obj: DescribeUserProfileRequest) => any;
}
export interface DescribeUserProfileResult {
    
    userArn: string | undefined;
    
    displayName?: string;
    
    emailAddress?: string;
    
    sshPublicKey?: string;
    
    createdTimestamp: Date | undefined;
    
    lastModifiedTimestamp: Date | undefined;
}
export declare namespace DescribeUserProfileResult {
    
    const filterSensitiveLog: (obj: DescribeUserProfileResult) => any;
}

export declare class UserProfileNotFoundException extends __BaseException {
    readonly name: "UserProfileNotFoundException";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<UserProfileNotFoundException, __BaseException>);
}
export interface DisassociateTeamMemberRequest {
    
    projectId: string | undefined;
    
    userArn: string | undefined;
}
export declare namespace DisassociateTeamMemberRequest {
    
    const filterSensitiveLog: (obj: DisassociateTeamMemberRequest) => any;
}
export interface DisassociateTeamMemberResult {
}
export declare namespace DisassociateTeamMemberResult {
    
    const filterSensitiveLog: (obj: DisassociateTeamMemberResult) => any;
}

export declare class InvalidNextTokenException extends __BaseException {
    readonly name: "InvalidNextTokenException";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<InvalidNextTokenException, __BaseException>);
}
export interface ListProjectsRequest {
    
    nextToken?: string;
    
    maxResults?: number;
}
export declare namespace ListProjectsRequest {
    
    const filterSensitiveLog: (obj: ListProjectsRequest) => any;
}

export interface ProjectSummary {
    
    projectId?: string;
    
    projectArn?: string;
}
export declare namespace ProjectSummary {
    
    const filterSensitiveLog: (obj: ProjectSummary) => any;
}
export interface ListProjectsResult {
    
    projects: ProjectSummary[] | undefined;
    
    nextToken?: string;
}
export declare namespace ListProjectsResult {
    
    const filterSensitiveLog: (obj: ListProjectsResult) => any;
}
export interface ListResourcesRequest {
    
    projectId: string | undefined;
    
    nextToken?: string;
    
    maxResults?: number;
}
export declare namespace ListResourcesRequest {
    
    const filterSensitiveLog: (obj: ListResourcesRequest) => any;
}

export interface Resource {
    
    id: string | undefined;
}
export declare namespace Resource {
    
    const filterSensitiveLog: (obj: Resource) => any;
}
export interface ListResourcesResult {
    
    resources?: Resource[];
    
    nextToken?: string;
}
export declare namespace ListResourcesResult {
    
    const filterSensitiveLog: (obj: ListResourcesResult) => any;
}
export interface ListTagsForProjectRequest {
    
    id: string | undefined;
    
    nextToken?: string;
    
    maxResults?: number;
}
export declare namespace ListTagsForProjectRequest {
    
    const filterSensitiveLog: (obj: ListTagsForProjectRequest) => any;
}
export interface ListTagsForProjectResult {
    
    tags?: {
        [key: string]: string;
    };
    
    nextToken?: string;
}
export declare namespace ListTagsForProjectResult {
    
    const filterSensitiveLog: (obj: ListTagsForProjectResult) => any;
}
export interface ListTeamMembersRequest {
    
    projectId: string | undefined;
    
    nextToken?: string;
    
    maxResults?: number;
}
export declare namespace ListTeamMembersRequest {
    
    const filterSensitiveLog: (obj: ListTeamMembersRequest) => any;
}

export interface TeamMember {
    
    userArn: string | undefined;
    
    projectRole: string | undefined;
    
    remoteAccessAllowed?: boolean;
}
export declare namespace TeamMember {
    
    const filterSensitiveLog: (obj: TeamMember) => any;
}
export interface ListTeamMembersResult {
    
    teamMembers: TeamMember[] | undefined;
    
    nextToken?: string;
}
export declare namespace ListTeamMembersResult {
    
    const filterSensitiveLog: (obj: ListTeamMembersResult) => any;
}
export interface ListUserProfilesRequest {
    
    nextToken?: string;
    
    maxResults?: number;
}
export declare namespace ListUserProfilesRequest {
    
    const filterSensitiveLog: (obj: ListUserProfilesRequest) => any;
}

export interface UserProfileSummary {
    
    userArn?: string;
    
    displayName?: string;
    
    emailAddress?: string;
    
    sshPublicKey?: string;
}
export declare namespace UserProfileSummary {
    
    const filterSensitiveLog: (obj: UserProfileSummary) => any;
}
export interface ListUserProfilesResult {
    
    userProfiles: UserProfileSummary[] | undefined;
    
    nextToken?: string;
}
export declare namespace ListUserProfilesResult {
    
    const filterSensitiveLog: (obj: ListUserProfilesResult) => any;
}
export interface TagProjectRequest {
    
    id: string | undefined;
    
    tags: {
        [key: string]: string;
    } | undefined;
}
export declare namespace TagProjectRequest {
    
    const filterSensitiveLog: (obj: TagProjectRequest) => any;
}
export interface TagProjectResult {
    
    tags?: {
        [key: string]: string;
    };
}
export declare namespace TagProjectResult {
    
    const filterSensitiveLog: (obj: TagProjectResult) => any;
}
export interface UntagProjectRequest {
    
    id: string | undefined;
    
    tags: string[] | undefined;
}
export declare namespace UntagProjectRequest {
    
    const filterSensitiveLog: (obj: UntagProjectRequest) => any;
}
export interface UntagProjectResult {
}
export declare namespace UntagProjectResult {
    
    const filterSensitiveLog: (obj: UntagProjectResult) => any;
}
export interface UpdateProjectRequest {
    
    id: string | undefined;
    
    name?: string;
    
    description?: string;
}
export declare namespace UpdateProjectRequest {
    
    const filterSensitiveLog: (obj: UpdateProjectRequest) => any;
}
export interface UpdateProjectResult {
}
export declare namespace UpdateProjectResult {
    
    const filterSensitiveLog: (obj: UpdateProjectResult) => any;
}

export declare class TeamMemberNotFoundException extends __BaseException {
    readonly name: "TeamMemberNotFoundException";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<TeamMemberNotFoundException, __BaseException>);
}
export interface UpdateTeamMemberRequest {
    
    projectId: string | undefined;
    
    userArn: string | undefined;
    
    projectRole?: string;
    
    remoteAccessAllowed?: boolean;
}
export declare namespace UpdateTeamMemberRequest {
    
    const filterSensitiveLog: (obj: UpdateTeamMemberRequest) => any;
}
export interface UpdateTeamMemberResult {
    
    userArn?: string;
    
    projectRole?: string;
    
    remoteAccessAllowed?: boolean;
}
export declare namespace UpdateTeamMemberResult {
    
    const filterSensitiveLog: (obj: UpdateTeamMemberResult) => any;
}
export interface UpdateUserProfileRequest {
    
    userArn: string | undefined;
    
    displayName?: string;
    
    emailAddress?: string;
    
    sshPublicKey?: string;
}
export declare namespace UpdateUserProfileRequest {
    
    const filterSensitiveLog: (obj: UpdateUserProfileRequest) => any;
}
export interface UpdateUserProfileResult {
    
    userArn: string | undefined;
    
    displayName?: string;
    
    emailAddress?: string;
    
    sshPublicKey?: string;
    
    createdTimestamp?: Date;
    
    lastModifiedTimestamp?: Date;
}
export declare namespace UpdateUserProfileResult {
    
    const filterSensitiveLog: (obj: UpdateUserProfileResult) => any;
}
